pub struct PutParameters {
pub api: Option<String>,
pub data: Option<String>,
pub delete: Option<String>,
pub digest: Option<String>,
pub disable: Option<bool>,
pub nodes: Option<String>,
pub validation_delay: Option<u64>,
}Fields
api: Option<String>API plugin name
data: Option<String>DNS plugin data. (base64 encoded)
delete: Option<String>A list of settings you want to delete.
digest: Option<String>Prevent changes if current configuration file has different SHA1 digest. This can be used to prevent concurrent modifications.
disable: Option<bool>Flag to disable the config.
nodes: Option<String>List of cluster node names.
validation_delay: Option<u64>Extra delay in seconds to wait before requesting validation. Allows to cope with a long TTL of DNS records.