PutParameters

Struct PutParameters 

pub struct PutParameters {
Show 22 fields pub bwlimit: Option<String>, pub console: Option<String>, pub crs: Option<String>, pub delete: Option<String>, pub description: Option<String>, pub email_from: Option<String>, pub fencing: Option<String>, pub ha: Option<String>, pub http_proxy: Option<String>, pub keyboard: Option<String>, pub language: Option<String>, pub mac_prefix: Option<String>, pub max_workers: Option<u64>, pub migration: Option<String>, pub migration_unsecure: Option<bool>, pub next_id: Option<String>, pub notify: Option<String>, pub registered_tags: Option<String>, pub tag_style: Option<String>, pub u2f: Option<String>, pub user_tag_access: Option<String>, pub webauthn: Option<String>,
}

Fields

bwlimit: Option<String>

Set bandwidth/io limits various operations.

console: Option<String>

Select the default Console viewer. You can either use the builtin java applet (VNC; deprecated and maps to html5), an external virt-viewer comtatible application (SPICE), an HTML5 based vnc viewer (noVNC), or an HTML5 based console client (xtermjs). If the selected viewer is not available (e.g. SPICE not activated for the VM), the fallback is noVNC.

crs: Option<String>

Cluster resource scheduling settings.

delete: Option<String>

A list of settings you want to delete.

description: Option<String>

Datacenter description. Shown in the web-interface datacenter notes panel. This is saved as comment inside the configuration file.

email_from: Option<String>

Specify email address to send notification from (default is root@$hostname)

fencing: Option<String>

Set the fencing mode of the HA cluster. Hardware mode needs a valid configuration of fence devices in /etc/pve/ha/fence.cfg. With both all two modes are used. WARNING: ‘hardware’ and ‘both’ are EXPERIMENTAL & WIP

ha: Option<String>

Cluster wide HA settings.

http_proxy: Option<String>

Specify external http proxy which is used for downloads (example: ‘http://username:password@host:port/’)

keyboard: Option<String>

Default keybord layout for vnc server.

language: Option<String>

Default GUI language.

mac_prefix: Option<String>

Prefix for autogenerated MAC addresses.

max_workers: Option<u64>

Defines how many workers (per node) are maximal started on actions like ‘stopall VMs’ or task from the ha-manager.

migration: Option<String>

For cluster wide migration settings.

migration_unsecure: Option<bool>

Migration is secure using SSH tunnel by default. For secure private networks you can disable it to speed up migration. Deprecated, use the ‘migration’ property instead!

next_id: Option<String>

Control the range for the free VMID auto-selection pool.

notify: Option<String>

Cluster-wide notification settings.

registered_tags: Option<String>

A list of tags that require a Sys.Modify on ‘/’ to set and delete. Tags set here that are also in ‘user-tag-access’ also require Sys.Modify.

tag_style: Option<String>

Tag style options.

u2f: Option<String>

u2f

user_tag_access: Option<String>

Privilege options for user-settable tags

webauthn: Option<String>

webauthn configuration