pub struct PostParameters {
pub comment: Option<String>,
pub disable: Option<bool>,
pub id: String,
pub rate: Option<f64>,
pub remove_job: Option<String>,
pub schedule: Option<String>,
pub source: Option<String>,
pub target: String,
pub type: String,
}Fields
comment: Option<String>Description.
disable: Option<bool>Flag to disable/deactivate the entry.
id: StringReplication Job ID. The ID is composed of a Guest ID and a job number, separated by a hyphen, i.e. ‘
rate: Option<f64>Rate limit in mbps (megabytes per second) as floating point number.
remove_job: Option<String>Mark the replication job for removal. The job will remove all local replication snapshots. When set to ‘full’, it also tries to remove replicated volumes on the target. The job then removes itself from the configuration file.
schedule: Option<String>Storage replication schedule. The format is a subset of systemd calendar events.
source: Option<String>For internal use, to detect if the guest was stolen.
target: StringTarget node.
type: StringSection type.