pub struct PostParameters {
pub add_storages: Option<bool>,
pub application: Option<String>,
pub crush_rule: Option<String>,
pub erasure_coding: Option<String>,
pub min_size: Option<u64>,
pub name: String,
pub pg_autoscale_mode: Option<String>,
pub pg_num: Option<u64>,
pub pg_num_min: Option<u64>,
pub size: Option<u64>,
pub target_size: Option<String>,
pub target_size_ratio: Option<f64>,
}Fields
add_storages: Option<bool>Configure VM and CT storage using the new pool.
application: Option<String>The application of the pool.
crush_rule: Option<String>The rule to use for mapping object placement in the cluster.
erasure_coding: Option<String>Create an erasure coded pool for RBD with an accompaning replicated pool for metadata storage. With EC, the common ceph options ‘size’, ‘min_size’ and ‘crush_rule’ parameters will be applied to the metadata pool.
min_size: Option<u64>Minimum number of replicas per object
name: StringThe name of the pool. It must be unique.
pg_autoscale_mode: Option<String>The automatic PG scaling mode of the pool.
pg_num: Option<u64>Number of placement groups.
pg_num_min: Option<u64>Minimal number of placement groups.
size: Option<u64>Number of replicas per object
target_size: Option<String>The estimated target size of the pool for the PG autoscaler.
target_size_ratio: Option<f64>The estimated target ratio of the pool for the PG autoscaler.